@@ -1,6 +1,15 @@
+require 'fileutils'
+
 module Kz
   EXIT_PROCS = []
   class << self
+    def barrier(default=nil)
+      yield
+    rescue Exception
+      print_error($!)
+      default
+    end
+
     def print_warning(message)
       STDERR.puts("** KzRuby WARNING **: #{message}")
     end
@@ -39,6 +48,14 @@ module Kz
   begin
     require 'gtk2'
     ENABLE = true
+    TMP_DIR = File.join(GLib.tmp_dir, PACKAGE)
+    barrier do
+      FileUtils.rm_rf(TMP_DIR)
+      FileUtils.mkdir_p(TMP_DIR)
+      add_exit_proc do
+        FileUtils.rm_rf(TMP_DIR)
+      end
+    end
   rescue Exception
     ENABLE = false
     print_warning(_("Ruby extension disabled: failed require 'gtk2'"))
