@@ -26,7 +26,7 @@ end
 
 def act_move_to_next_anchor_config(config, kz)
   config[:label] = N_("Move to previous anchor")
-  config[:tooltip] = N_("move to previous anchor")
+  config[:tooltip] = N_("Move to previous anchor")
 end
 
 def act_move_to_next_anchor(action, group, kz)
@@ -41,5 +41,5 @@ end
 
 def act_move_to_next_anchor_config(config, kz)
   config[:label] = N_("Move to next anchor")
-  config[:tooltip] = N_("move to next anchor")
+  config[:tooltip] = N_("Move to next anchor")
 end
