@@ -92,6 +92,13 @@ act_tab_close (GtkAction *action, KzWindow *kz)
 	kz_window_close_tab(kztab->kz, GTK_WIDGET(kztab->kzembed));
 }
 
+enum {
+	KZ_TAB_CLOSE_ALL_TABS = -1,
+	KZ_TAB_CLOSE_INACTIVE,
+	KZ_TAB_CLOSE_BACKWARD,
+	KZ_TAB_CLOSE_FORWARD
+};
+
 static void
 close_all_tab (GtkAction *action, KzWindow *kz, gint mode)
 {
@@ -100,6 +107,12 @@ close_all_tab (GtkAction *action, KzWindow *kz, gint mode)
 	gint num, pos;
 	gint i;
 
+	if(mode == KZ_TAB_CLOSE_ALL_TABS)
+	{
+		kz_window_close_all_tab(kz);
+		return;
+	}
+
 	g_return_if_fail(KZ_IS_WINDOW(kz));
 
 	kztab = g_object_get_qdata(G_OBJECT(kz), kztab_quark);
@@ -116,8 +129,8 @@ close_all_tab (GtkAction *action, KzWindow *kz, gint mode)
 		GtkWidget *widget = KZ_WINDOW_NTH_PAGE(kztab->kz, i);
 
 		if (i == pos) continue;
-		if (i > pos && mode == 1) continue;
-		if (i < pos && mode == 2) continue;
+		if (i > pos && mode == KZ_TAB_CLOSE_BACKWARD) continue;
+		if (i < pos && mode == KZ_TAB_CLOSE_FORWARD) continue;
 
 		kz_window_close_tab(kztab->kz, widget);
 	}
@@ -126,21 +139,26 @@ close_all_tab (GtkAction *action, KzWindow *kz, gint mode)
 static void
 act_tab_close_left (GtkAction *action, KzWindow *kz)
 {
-	close_all_tab(action, kz, 1);
+	close_all_tab(action, kz, KZ_TAB_CLOSE_BACKWARD);
 }
 
 static void
 act_tab_close_right (GtkAction *action, KzWindow *kz)
 {
-	close_all_tab(action, kz, 2);
+	close_all_tab(action, kz, KZ_TAB_CLOSE_FORWARD);
 }
 
 static void
 act_tab_close_all_inactive_active (GtkAction *action, KzWindow *kz)
 {
-	close_all_tab(action, kz, 0);
+	close_all_tab(action, kz, KZ_TAB_CLOSE_INACTIVE);
 }
 
+static void
+act_tab_close_all_tabs (GtkAction *action, KzWindow *kz)
+{
+	close_all_tab(action, kz, KZ_TAB_CLOSE_ALL_TABS);
+}
 
 static gboolean
 get_all_under_current_tab (GNode *node, gpointer data)
@@ -346,7 +364,7 @@ act_tab_copy_tab (GtkAction *action, KzWindow *kz)
 	kzembed  = KZ_EMBED(widget);	
 	dkzembed = KZ_EMBED(kz_window_open_new_tab(kz, NULL));
 
-	kz_embed_copy_page(kzembed, dkzembed);
+	kz_embed_copy_page(kzembed, dkzembed, KZ_EMBED_COPY_NORMAL);
 	kz_embed_shistory_copy(kzembed, dkzembed, TRUE, TRUE, TRUE);
 }
 
@@ -377,6 +395,9 @@ GtkActionEntry kz_actions_tab[] =
 	{"TabCloseAllInactiveTabs", GTK_STOCK_CLOSE, N_("Close all _inactive tabs"),
 	 NULL, NULL, G_CALLBACK(act_tab_close_all_inactive_active)},
 
+	{"TabCloseAllTabs", GTK_STOCK_CLOSE, N_("Clos_e all tabs"),
+	 NULL, NULL, G_CALLBACK(act_tab_close_all_tabs)},
+
 	{"TabCloseAllChild", GTK_STOCK_CLOSE, N_("Close all c_hild tab"),
 	 NULL, NULL, G_CALLBACK(act_tab_close_all_child)},
 
@@ -413,10 +434,9 @@ const gint kz_toggle_actions_tab_len = G_N_ELEMENTS(kz_toggle_actions_tab);
 
 
 GtkActionGroup *
-kz_actions_tab_popup_create_group (KzWindow *kz, GtkAccelGroup *accel_group)
+kz_actions_tab_popup_create_group (KzWindow *kz)
 {
 	GtkActionGroup *action_group;
-	GList *node, *action_list;
 
 	action_group = gtk_action_group_new("KzWindowTabPopup");
 
@@ -431,16 +451,6 @@ kz_actions_tab_popup_create_group (KzWindow *kz, GtkAccelGroup *accel_group)
 					    kz_toggle_actions_tab,
 					    kz_toggle_actions_tab_len,
 					    kz);
-	
-	action_list = gtk_action_group_list_actions(action_group);
-	
-	for (node = action_list; node; node = g_list_next(node))
-	{
-		gtk_action_set_accel_group(GTK_ACTION(node->data),
-					   accel_group);
-		gtk_action_connect_accelerator(GTK_ACTION(node->data));
-	}
-	g_list_free(action_list);
 
 	return action_group;
 }
