@@ -260,41 +260,6 @@ kz_history_action_activate (GtkAction *action)
 }
 
 
-#if 0
-static gboolean
-cb_menu_item_combo_button_press (GtkWidget *widget)
-{
-	/* don't propagate to parent */
-	return TRUE;
-}
-
-
-static gboolean
-cb_menu_item_combo_button_release (GtkWidget *widget)
-{
-	/* don't propagate to parent */
-	return TRUE;
-}
-
-
-static gboolean
-cb_menu_item_combo_enter (GtkWidget *widget, GdkEventCrossing *event)
-{
-	gtk_grab_add(GTK_BIN(widget)->child);
-	gtk_widget_grab_focus(GTK_BIN(widget)->child);
-
-	return TRUE;
-}
-
-
-static gboolean
-cb_menu_item_combo_leave (GtkWidget *widget, GdkEventCrossing *event)
-{
-	gtk_grab_remove(GTK_BIN(widget)->child);
-
-	return TRUE;
-}
-#endif
 
 static gboolean
 cb_match_selected (GtkEntryCompletion *completion,
@@ -428,19 +393,7 @@ kz_history_action_create_menu_item (GtkAction *action)
 	gtk_widget_show(combo);
 	gtk_container_add(GTK_CONTAINER(widget), combo);
 	gtk_combo_box_set_active(GTK_COMBO_BOX(combo), 0);
-#if 0
-	g_signal_connect_after(widget, "button-press-event",
-			       G_CALLBACK(cb_menu_item_combo_button_press),
-			       NULL);
-	g_signal_connect_after(widget, "button-release-event",
-			       G_CALLBACK(cb_menu_item_combo_button_release),
-			       NULL);
-
-	g_signal_connect(widget, "enter-notify-event",
-			 G_CALLBACK(cb_menu_item_combo_enter), NULL);
-	g_signal_connect(widget, "leave-notify-event",
-			 G_CALLBACK(cb_menu_item_combo_leave), NULL);
-#endif
+	
 	return widget;
 }
 
@@ -473,7 +426,6 @@ kz_history_action_connect_proxy (GtkAction *action, GtkWidget *proxy)
 
 	g_return_if_fail(proxy);
 
-
 	combo = kz_history_action_get_combo_widget(KZ_HISTORY_ACTION(action),
 						   proxy);
 	if (GTK_IS_COMBO_BOX(combo))
@@ -487,12 +439,10 @@ kz_history_action_connect_proxy (GtkAction *action, GtkWidget *proxy)
 static GtkComboBox *
 kz_history_action_real_get_combo_widget (KzHistoryAction *action, GtkWidget *proxy)
 {
-	GtkComboBox *combo = NULL;
-
 	g_return_val_if_fail(proxy, NULL);
 
-	if (GTK_IS_COMBO_BOX(combo))
-		return combo;
+	if (GTK_IS_COMBO_BOX(proxy))
+		return GTK_COMBO_BOX(proxy);
 
 	return NULL;
 }
