@@ -30,7 +30,6 @@
 static void kz_bookmark_edit_win_class_init (KzBookmarkEditWinClass *klass);
 static void kz_bookmark_edit_win_init       (KzBookmarkEditWin      *win);
 static void kz_bookmark_edit_win_dispose    (GObject                *object);
-static void kz_bookmark_edit_win_finalize   (GObject                *finalize);
 static void kz_bookmark_edit_win_response   (GtkDialog              *dialog,
 					     gint                    arg);
 
@@ -40,7 +39,6 @@ static GtkDialogClass *parent_class = NULL;
 KZ_OBJECT_GET_TYPE(kz_bookmark_edit_win, "KzBookmarkEditWin", KzBookmarkEditWin,
 		   kz_bookmark_edit_win_class_init, kz_bookmark_edit_win_init,
 		   GTK_TYPE_DIALOG)
-KZ_OBJECT_FINALIZE(kz_bookmark_edit_win, KzBookmarkEditWin)
 
 
 static void
@@ -54,7 +52,6 @@ kz_bookmark_edit_win_class_init (KzBookmarkEditWinClass *klass)
 	dialog_class = (GtkDialogClass *) klass;
 
 	object_class->dispose  = kz_bookmark_edit_win_dispose;
-	object_class->finalize = kz_bookmark_edit_win_finalize;
 
 	dialog_class->response = kz_bookmark_edit_win_response;
 }
@@ -65,8 +62,6 @@ kz_bookmark_edit_win_init (KzBookmarkEditWin *win)
 {
 	GtkWidget *edit;
 
-	win->priv = NULL;
-
 	gtk_window_set_default_size(GTK_WINDOW(win), 600, 400);
 	gtk_window_set_icon(GTK_WINDOW(win), kz_icon);
 
