@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmark-item.h,v 1.2 2004/11/25 07:28:47 ikezoe Exp $
+ *  $Id: kz-bookmark-item.h,v 1.4 2005/07/18 10:53:25 ikezoe Exp $
  */
 
 #ifndef __KZ_BOOKMARK_ITEM_H__
@@ -32,17 +32,17 @@ G_BEGIN_DECLS
 
 #define KZ_TYPE_BOOKMARK_ITEM		(kz_bookmark_item_get_type ())
 #define KZ_BOOKMARK_ITEM(obj)		(G_TYPE_CHECK_INSTANCE_CAST ((obj), KZ_TYPE_BOOKMARK_ITEM, KzBookmarkItem))
-#define KZ_BOOKMARK_ITEM_CLASS(klass)	(G_TYPE_CHECK_CLASS_CAST ((klass),  KZ_TYPE_Bookmark_ITEM, KzBookmarkItemClass))
+#define KZ_BOOKMARK_ITEM_CLASS(klass)	(G_TYPE_CHECK_CLASS_CAST ((klass),  KZ_TYPE_BOOKMARK_ITEM, KzBookmarkItemClass))
 #define KZ_IS_BOOKMARK_ITEM(obj)	(G_TYPE_CHECK_INSTANCE_TYPE ((obj), KZ_TYPE_BOOKMARK_ITEM))
 #define KZ_IS_BOOKMARK_ITEM_CLASS(klass)(G_TYPE_CHECK_CLASS_TYPE ((klass),  KZ_TYPE_BOOKMARK_ITEM))
-#define KZ_BOOKMARK_ITEM_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS ((obj),  KZ_TYPE_Bookmark_ITEM, KzBookmarkItemClass))
+#define KZ_BOOKMARK_ITEM_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS ((obj),  KZ_TYPE_BOOKMARK_ITEM, KzBookmarkItemClass))
 
 typedef struct _KzBookmarkItem           KzBookmarkItem;
 typedef struct _KzBookmarkItemClass      KzBookmarkItemClass;
 
 struct _KzBookmarkItem
 {
-	GtkHBox parent;
+	GtkToolItem parent;
 
 	/* Parent Kazehakase */
 	KzWindow *kz;
@@ -59,11 +59,11 @@ struct _KzBookmarkItem
 
 struct _KzBookmarkItemClass
 {
-	GtkHBoxClass parent_class;
+	GtkToolItemClass parent_class;
 };
 
-GType      kz_bookmark_item_get_type (void) G_GNUC_CONST;
-GtkWidget *kz_bookmark_item_new      (KzWindow *kz, KzBookmark *bookmark);
+GType        kz_bookmark_item_get_type (void) G_GNUC_CONST;
+GtkToolItem *kz_bookmark_item_new      (KzWindow *kz, KzBookmark *bookmark);
 
 G_END_DECLS
 
