@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmark.c,v 1.79 2006/01/15 04:52:24 kous Exp $
+ *  $Id: kz-bookmark.c,v 1.80 2006/04/23 14:42:25 kous Exp $
  */
 
 #include "kz-bookmark.h"
@@ -1085,9 +1085,9 @@ kz_bookmark_sort (KzBookmark *bookmark, const gchar *type)
 
 
 void
-kz_bookmark_regist_sort_func (const gchar *type, GCompareFunc *func)
+kz_bookmark_register_sort_func (const gchar *type, GCompareFunc *func)
 {
-	g_warning("kz_bookmark_regist_sort_func() is not implemented yet.");
+	g_warning("kz_bookmark_register_sort_func() is not implemented yet.");
 }
 
 
