@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmark.h,v 1.35 2006/01/15 04:52:25 kous Exp $
+ *  $Id: kz-bookmark.h,v 1.36 2006/04/23 14:42:25 kous Exp $
  */
 
 #ifndef __KZ_BOOKMARK_H__
@@ -158,7 +158,7 @@ gboolean	kz_bookmark_get_javascript	(KzBookmark  *bookmark);
 void		kz_bookmark_set_javascript	(KzBookmark  *bookmark,
 						 gboolean javascript);
 
-void		kz_bookmark_regist_sort_func	(const gchar *type,
+void		kz_bookmark_register_sort_func	(const gchar *type,
 						 GCompareFunc *func);
 
 KzBookmark *    kz_bookmark_find_bookmark_from_uri (KzBookmark *bookmark,
