@@ -60,7 +60,7 @@ kz_lirs_is_supported (KzBookmarkFile *bookmark, const gchar *buf)
 {
 	g_return_val_if_fail(buf, FALSE);
 
-	if (strncmp(buf, "LIRS", 4) == 0)
+	if (g_str_has_prefix(buf, "LIRS"))
 		return TRUE;
 
 	return FALSE;
