@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-root-bookmark.c,v 1.13 2005/02/13 22:55:15 ikezoe Exp $
+ *  $Id: kz-root-bookmark.c,v 1.14 2005/11/24 06:41:51 ikezoe Exp $
  */
 
 #include "kz-root-bookmark.h"
@@ -348,19 +348,9 @@ kz_root_bookmark_add_current_session_file (KzRootBookmark *root,
 	g_return_if_fail(root->current_session);
 
 	/* FIXME! Check permission */
-
-	if (g_file_test(file, G_FILE_TEST_EXISTS))
-	{
-		current_session = kz_bookmark_file_new(file,
-					   _("Current Session"),
-					   "XBEL");
-	}
-	else
-	{
-		current_session = kz_bookmark_file_create_new(file,
-						  _("Current Session"),
-						  "XBEL");
-	}
+	current_session = kz_bookmark_file_create_new(file,
+					  _("Current Session"),
+					  "XBEL");
 
 	if (root->current_session)
 	{
@@ -370,7 +360,6 @@ kz_root_bookmark_add_current_session_file (KzRootBookmark *root,
 
 	if (current_session)
 	{
-		kz_bookmark_file_load(current_session);
 		root->current_session = KZ_BOOKMARK(current_session);
 		/*	
 		kz_bookmark_insert_before(KZ_BOOKMARK(root),
