@@ -30,6 +30,7 @@
 #include "kz-downloader.h"
 #include "utils.h"
 #include "glib-utils.h"
+#include <glib/gstdio.h>
 
 typedef struct _KzFaviconPrivate	KzFaviconPrivate;
 struct _KzFaviconPrivate
@@ -49,6 +50,12 @@ enum {
 
 #define MAX_FAVICONS 2000
 
+typedef struct downloader_info
+{
+	const gchar *document_uri;
+	gchar *favicon_file_location;
+} downloader_info_t;
+
 static void kz_favicon_class_init   (KzFaviconClass *klass);
 static void kz_favicon_init         (KzFavicon *kzfav);
 static void kz_favicon_dispose      (GObject *object);
@@ -59,9 +66,12 @@ static void kz_favicon_uri_hash_to_uri_list (gpointer key,
 					     KzFavicon *kzfav);
 
 static void cb_downloader_load_complete (KzDownloader *dl,
-					 const gchar *uri);
+					 downloader_info_t *info);
 static void cb_downloader_load_error    (KzDownloader *dl,
-					 const gchar *uri);
+					 downloader_info_t *info);
+
+static const gchar *kz_favicon_get_favicon_file_name (KzFavicon *kzfav,
+						      const gchar *uri);
 
 static GObjectClass *parent_class     = NULL;
 static KzFavicon    *kzfavicon_single = NULL;
@@ -231,47 +241,67 @@ idle_unref_dl(gpointer data)
 
 
 static void
-kz_downloader_disconnect_signal(KzDownloader *dl, const gchar *uri)
+kz_downloader_disconnect_signal(KzDownloader *dl, downloader_info_t *info)
 {
 	g_signal_handlers_disconnect_by_func(dl,
 					     G_CALLBACK(cb_downloader_load_complete),
-					     (gpointer)uri);
+					     (gpointer)info);
 	g_signal_handlers_disconnect_by_func(dl,
 					     G_CALLBACK(cb_downloader_load_error),
-					     (gpointer)uri);
+					     (gpointer)info);
 }
 
 static void
-cb_downloader_load_complete (KzDownloader *dl, const gchar *uri)
+cb_downloader_load_complete (KzDownloader *dl, downloader_info_t *info)
 {	
 	GQuark quark;
-
-	quark = g_quark_from_string(uri);
-
-	kz_downloader_disconnect_signal(dl, uri);
-	g_idle_add(idle_unref_dl, dl);
-
-	/* FIXME! Do not use kzfavicon_sigle object! */
-	g_signal_emit(kzfavicon_single,
-		      kz_favicon_signals[READY_SIGNAL],
-		      quark,
-		      uri);	
-}
-
-
-static void
-cb_downloader_load_error (KzDownloader *dl, const gchar *uri)
-{
-	gchar *hash_key;
+	const gchar *uri;
 	KzFavicon *kzfav = kzfavicon_single;
 	KzFaviconPrivate *priv = KZ_FAVICON_GET_PRIVATE (kzfav);
 
-	kz_downloader_disconnect_signal(dl, uri);
+	uri = info->document_uri;
+	quark = g_quark_from_string(uri);
+
+	kz_downloader_disconnect_signal(dl, info);
+
+	if (!g_file_set_contents(info->favicon_file_location,
+				 kz_downloader_get_string(dl),
+				 kz_downloader_get_size(dl),
+				 NULL) &&
+	    g_file_test(info->favicon_file_location, G_FILE_TEST_EXISTS))
+	{
+		g_unlink(info->favicon_file_location);
+		g_free(info->favicon_file_location);
+	}
+	else
+	{
+		g_hash_table_insert(priv->uri_hash,
+		 create_profile_key_from_uri(uri), 
+		 info->favicon_file_location);
+	}
+	g_free(info);
+
 	g_idle_add(idle_unref_dl, dl);
 
-	hash_key = create_profile_key_from_uri(uri);
-	g_hash_table_remove(priv->uri_hash, hash_key);
-	g_free(hash_key);	
+	/* FIXME! Do not use kzfavicon_sigle object! */
+	g_signal_emit(kzfav,
+		      kz_favicon_signals[READY_SIGNAL],
+		      quark,
+		      uri);
+}
+
+
+static void
+cb_downloader_load_error (KzDownloader *dl, downloader_info_t *info)
+{
+	gchar *uri;
+	uri = info->document_uri;
+
+	kz_downloader_disconnect_signal(dl, info);
+	g_idle_add(idle_unref_dl, dl);
+
+	g_free(info->favicon_file_location);
+	g_free(info);
 }
 
 
@@ -293,13 +323,34 @@ kz_favicon_get_widget (KzFavicon *kzfav, const gchar *uri, GtkIconSize size)
 	return icon;
 }
 
+static const gchar *
+kz_favicon_get_favicon_file_name (KzFavicon *kzfav, const gchar *uri)
+{
+	KzFaviconPrivate *priv = KZ_FAVICON_GET_PRIVATE (kzfav);
+	gchar *hash_key;
+	const gchar *favicon_file_name;
+
+	if (!priv) return NULL;
+
+	hash_key = create_profile_key_from_uri(uri);
+	favicon_file_name = g_hash_table_lookup(priv->uri_hash, hash_key);
+	g_free(hash_key);
+
+	return favicon_file_name;
+}
+
+gboolean
+kz_favicon_is_loaded (KzFavicon *kzfav, const gchar *uri)
+{
+	return kz_favicon_get_favicon_file_name(kzfav, uri) ? TRUE : FALSE;
+}
+
 GdkPixbuf *
 kz_favicon_get_pixbuf (KzFavicon *kzfav, const gchar *uri, GtkIconSize size)
 {
 	GdkPixbuf *icon = NULL;
 	GdkPixbuf *pixbuf;
 	const gchar *favicon_file_name;
-	gchar *hash_key;
 	gint width, height;
 	KzFaviconPrivate *priv = KZ_FAVICON_GET_PRIVATE (kzfav);
 
@@ -308,10 +359,7 @@ kz_favicon_get_pixbuf (KzFavicon *kzfav, const gchar *uri, GtkIconSize size)
 	if (uri == NULL)
 		return NULL;
 
-	hash_key = create_profile_key_from_uri(uri);
-	favicon_file_name = g_hash_table_lookup(priv->uri_hash, hash_key);
-	g_free(hash_key);
-
+	favicon_file_name = kz_favicon_get_favicon_file_name(kzfav, uri);
 	if (!favicon_file_name)
 		return NULL;
 
@@ -343,7 +391,6 @@ kz_favicon_get_icon_from_uri (KzFavicon *kzfav,
 {
 	gchar *favicon_filename;
 	gchar *favicon_file_location;
-	gchar *hash_key;
 	const gchar *old_value;
 	KzDownloader *dl;
 	KzFaviconPrivate *priv;
@@ -352,7 +399,6 @@ kz_favicon_get_icon_from_uri (KzFavicon *kzfav,
 	priv = KZ_FAVICON_GET_PRIVATE (kzfav);
 
 	if (!uri) return;
-	hash_key = create_profile_key_from_uri(document_uri);
 
 	favicon_filename = create_filename_from_uri(uri);
 	favicon_file_location = g_build_filename(g_get_home_dir(),
@@ -362,9 +408,7 @@ kz_favicon_get_icon_from_uri (KzFavicon *kzfav,
 					    	 NULL);
 	g_free(favicon_filename);
 	
-	old_value = g_hash_table_lookup(priv->uri_hash,
-					hash_key);
-	
+	old_value = kz_favicon_get_favicon_file_name(kzfav, document_uri);
 	if (old_value && !strcmp(old_value, favicon_file_location))
 	{
 		GQuark quark;
@@ -374,29 +418,29 @@ kz_favicon_get_icon_from_uri (KzFavicon *kzfav,
 			      kz_favicon_signals[READY_SIGNAL],
 			      quark,
 			      document_uri);
-		g_free(hash_key);
 		g_free(favicon_file_location);
 		return;
 	}
 
-	g_hash_table_insert(priv->uri_hash,
-			    g_strdup(hash_key),
-			    g_strdup(favicon_file_location));
-
 	/* start download */
-	dl = kz_downloader_new_with_filename(uri, favicon_file_location);
+	dl = kz_downloader_new(uri);
 	if (dl)
 	{
+		downloader_info_t *info = g_new(downloader_info_t, 1);
+		info->document_uri = document_uri;
+		info->favicon_file_location = favicon_file_location;
+
 		g_signal_connect(dl, "completed",
 				 G_CALLBACK(cb_downloader_load_complete),
-				 (gpointer)document_uri);
+				 (gpointer)info);
 		g_signal_connect(dl, "error",
 				 G_CALLBACK(cb_downloader_load_error),
-				 (gpointer)document_uri);
-		kz_downloader_to_file(dl);
+				 (gpointer)info);
+		kz_downloader_to_buffer(dl);
+	}
+	else
+	{
+		g_free(favicon_file_location);
 	}
-
-	g_free(hash_key);
-	g_free(favicon_file_location);
 }
 
