@@ -40,6 +40,7 @@
 
 #include <stdio.h>
 #include <string.h>
+#include <glib/gstdio.h>
 #include "gobject-utils.h"
 #include "glib-utils.h"
 #include "kz-marshalers.h"
@@ -344,7 +345,7 @@ kz_profile_list (const gchar *file)
 	FILE *fio;
 	KzProfileList *p = NULL, *q, *r;
 
-	fio = fopen(file, "rt");
+	fio = g_fopen(file, "rt");
 	if (!fio)
 		return NULL;
 	while (fgets (buf, 256, fio))
@@ -489,7 +490,7 @@ kz_profile_save (KzProfile *profile)
 	if (!profile->edit) return TRUE;
 	if (!profile->file) return FALSE;
 
-	fio = fopen(profile->file, "wt");
+	fio = g_fopen(profile->file, "wt");
 	if (!fio) return FALSE;
 
 	/* when the profile was modified */
