@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-sidebar.c,v 1.18 2005/02/14 05:45:03 ikezoe Exp $
+ *  $Id: kz-sidebar.c,v 1.20 2006/08/25 15:06:38 kous Exp $
  */
 
 #include "kz-sidebar.h"
@@ -32,19 +32,12 @@
 #include "kz-tabtree.h"
 #include "kz-thumbnails-sidebar.h"
 
-
 #define ADD_ENTRIES(func) 						\
 {									\
 	KzSidebarEntry *entry;						\
 	gint i;								\
 	for (i = 0; (entry = func(i)); i++)				\
-	{								\
-		n_sidebar_entries++;					\
-		sidebar_entries = g_realloc(sidebar_entries,		\
-					    sizeof(KzSidebarEntry)	\
-					    * n_sidebar_entries);	\
-		sidebar_entries[n_sidebar_entries - 1] = entry;		\
-	}								\
+		kz_sidebar_append_entry (entry);			\
 }
 
 
@@ -79,6 +72,16 @@ static GtkVBoxClass *parent_class = NULL;
 static KzSidebarEntry **sidebar_entries   = NULL;
 static gint             n_sidebar_entries = 0;
 
+void
+kz_sidebar_append_entry(KzSidebarEntry *entry)
+{
+	n_sidebar_entries++;
+	sidebar_entries =
+		g_realloc(sidebar_entries,
+			  sizeof(KzSidebarEntry *) * n_sidebar_entries);
+	sidebar_entries[n_sidebar_entries - 1] = entry;
+}
+
 
 KZ_OBJECT_GET_TYPE(kz_sidebar, "KzSidebar", KzSidebar,
 		   kz_sidebar_class_init, kz_sidebar_init,
@@ -249,8 +252,8 @@ kz_sidebar_change_content (KzSidebar *sidebar, KzSidebarEntry *entry)
 	g_return_val_if_fail(entry, FALSE);
 	g_return_val_if_fail(entry->create, FALSE);
 
-	widget = entry->create(sidebar);
-	if (!GTK_IS_WIDGET(widget))
+	widget = entry->create(entry, sidebar);
+	if (!widget || !GTK_IS_WIDGET(widget))
 		return FALSE;
 
 	if (sidebar->content)
