@@ -59,49 +59,6 @@ KzMozProgressListener::OnStateChange(nsIWebProgress *aWebProgress,
 				     PRUint32        aStateFlags,
 				     nsresult        aStatus)
 {
-#if 0
-	if (aStateFlags & nsIWebProgressListener::STATE_START)
-	{
-		/* be sure to keep it alive while we save since it owns
-		   us as a listener and keep ourselves alive */
-		nsCOMPtr<nsIWebBrowserPersist> kungFuDeathGrip(mPersist);
-		nsCOMPtr<nsIWebProgressListener> kungFuSuicideGrip(this);
-    
-		nsresult rv;
-		nsCOMPtr<nsIChannel> channel = do_QueryInterface(aRequest, &rv);
-		if (!channel) return rv;
-		channel->GetContentType(mContentType);
-    
-		nsCOMPtr<nsIURI> origURI;
-		channel->GetOriginalURI(getter_AddRefs(origURI));
-    
-		nsCOMPtr<nsIHttpChannel> httpChannel(do_QueryInterface(channel));
-		if (httpChannel)
-		{
-			httpChannel->GetResponseHeader(nsEmbedCString("content-disposition"),
-						       mContentDisposition);
-		}
-    
-		mPersist->CancelSave();
-
-		PRBool exists;
-		mTmpFile->Exists(&exists);
-		if (exists)
-		{
-			mTmpFile->Remove(PR_FALSE);
-		}
-
-		rv = HandleContent ();
-		if (NS_SUCCEEDED (rv)) return NS_OK;
-
-		rv = PerformSave(origURI);
-		if (NS_FAILED(rv))
-		{
-			/* FIXME put up some UI */
-      
-		}
-	}
-#endif
 	if (aStateFlags & nsIWebProgressListener::STATE_STOP)
 	{
 		if (mPersist)
@@ -128,6 +85,28 @@ KzMozProgressListener::OnStateChange(nsIWebProgress *aWebProgress,
 	return NS_OK;
 }
 
+#ifdef HAVE_NSIWEBPROGRESSLISTENER2_H
+NS_IMETHODIMP
+KzMozProgressListener::OnProgressChange (nsIWebProgress *aWebProgress,
+			                 nsIRequest *aRequest,
+				       	 PRInt32 aCurSelfProgress,
+				       	 PRInt32 aMaxSelfProgress,
+				       	 PRInt32 aCurTotalProgress,
+				       	 PRInt32 aMaxTotalProgress)
+{
+	return OnProgressChange64 (aWebProgress, aRequest,
+				   aCurSelfProgress, aMaxSelfProgress,
+				   aCurTotalProgress, aMaxTotalProgress);
+}
+
+NS_IMETHODIMP
+KzMozProgressListener::OnProgressChange64(nsIWebProgress *aWebProgress,
+				          nsIRequest *aRequest,
+					  PRInt64 aCurSelfProgress,
+					  PRInt64 aMaxSelfProgress,
+					  PRInt64 aCurTotalProgress,
+					  PRInt64 aMaxTotalProgress)
+#else 
 NS_IMETHODIMP
 KzMozProgressListener::OnProgressChange(nsIWebProgress *aWebProgress,
 					nsIRequest     *aRequest,
@@ -135,6 +114,7 @@ KzMozProgressListener::OnProgressChange(nsIWebProgress *aWebProgress,
 					PRInt32         aMaxSelfProgress,
 					PRInt32         aCurTotalProgress,
 					PRInt32         aMaxTotalProgress)
+#endif
 {
 
 	mPercentComplete = (PRInt32)(((float)aCurTotalProgress / (float)aMaxTotalProgress) * 100.0 + 0.5);
@@ -173,21 +153,30 @@ KzMozProgressListener::OnSecurityChange(nsIWebProgress *aWebProgress,
 NS_IMETHODIMP
 KzMozProgressListener::Init(nsIURI *aSource,
 			    nsIURI *aTarget,
+#if HAVE_NSIWEBPROGRESSLISTENER2_H
+			    const nsAString &aDisplayName,
+			    nsIMIMEInfo *aMIMEInfo,
+			    PRTime aStartTime,
+		            nsILocalFile *aTempFile,
+		            nsICancelable *aCancelable)
+#else
 			    const PRUnichar *aDisplayName,
 			    nsIMIMEInfo *aMIMEInfo,
 			    PRInt64 startTime,
 			    nsIWebBrowserPersist *aPersist)
+#endif
 {
 	mTotalProgress = 0;
 	mCurrentProgress = 0;
 	mPercentComplete = 0;
 
+#ifndef HAVE_NSIWEBPROGRESSLISTENER2_H
 	if (aPersist)
 	{
 		mPersist = aPersist;
 		mPersist->SetProgressListener(this);
         }
-
+#endif
 	nsEmbedString leafName;
 
 	nsCOMPtr<nsIFileURL> fileUrl = do_QueryInterface(aTarget);
@@ -198,16 +187,11 @@ KzMozProgressListener::Init(nsIURI *aSource,
 		file->GetLeafName(leafName);
 	}
 	KzDownloaderGroup *dlgrp = kz_downloader_group_get_instance();
-#if 0
-	mDownloader = kz_downloader_group_add_moz_downloader(dlgrp,
-							     this,
-							     NS_ConvertUCS2toUTF8(leafName).get());
-#else
 	nsEmbedCString cLeafName;
 	NS_UTF16ToCString(leafName, NS_CSTRING_ENCODING_UTF8, cLeafName);
 	mDownloader = kz_moz_downloader_new(this, cLeafName.get());
 	kz_downloader_group_add_downloader(dlgrp, KZ_DOWNLOADER(mDownloader));
-#endif
+
 	g_object_unref(dlgrp);
 	return NS_OK;
 }
@@ -276,6 +260,7 @@ KzMozProgressListener::GetMIMEInfo(nsIMIMEInfo * *aMIMEInfo)
 	return NS_ERROR_NOT_IMPLEMENTED;
 }
 
+#ifndef HAVE_NSIWEBPROGRESSLISTENER2_H
 NS_IMETHODIMP
 KzMozProgressListener::GetListener(nsIWebProgressListener * *aListener)
 {
@@ -302,6 +287,7 @@ KzMozProgressListener::SetObserver(nsIObserver * aObserver)
         mObserver = aObserver;
 	return NS_OK;
 }
+#endif
 
 nsresult
 KzMozProgressListener::Cancel ()
