@@ -86,7 +86,6 @@ KzMozSelectionListener::NotifySelectionChanged (nsIDOMDocument *doc,
 						nsISelection *sel,
 						PRInt16 reason)
 {
-	g_print("notify selection changed\n");
 	g_signal_emit_by_name(mKzMozEmbed, "kz-selection");
 	return NS_OK;
 }
@@ -98,18 +97,20 @@ KzMozSelectionListener::AddSelectionListener (void)
 	nsresult rv;
 	nsCOMPtr<nsIDOMWindow> domWindow;
 
+	if (!mWebBrowser) return NS_ERROR_FAILURE;
+
 	nsCOMPtr<nsIWebBrowserFocus> focus = do_GetInterface(mWebBrowser, &rv);
 	if (NS_FAILED(rv) || !focus) return NS_ERROR_FAILURE;
 
 	rv = focus->GetFocusedWindow (getter_AddRefs(domWindow));
-	if (NS_FAILED(rv))
+	if (NS_FAILED(rv) || !domWindow)
 		rv = mWebBrowser->GetContentDOMWindow (getter_AddRefs(domWindow));
 	
-	if (NS_FAILED(rv)) return NS_ERROR_FAILURE;
+	if (NS_FAILED(rv) || !domWindow) return NS_ERROR_FAILURE;
 
 	nsCOMPtr<nsISelection> selection;
 	rv = domWindow->GetSelection(getter_AddRefs(selection));
-	if (!selection) return NS_ERROR_FAILURE;
+	if (NS_FAILED(rv) || !selection) return NS_ERROR_FAILURE;
 
 	nsCOMPtr<nsISelectionPrivate> selectionPriv;
 	selectionPriv = do_QueryInterface(selection);
