@@ -237,7 +237,6 @@ font_combo_set (GtkComboBox *combo,
 		i++;
 	}
 
-#if GTK_CHECK_VERSION(2,6,0)
 	/* for separator */
 	gtk_combo_box_append_text(combo, "---");
 	i++;
@@ -249,7 +248,6 @@ font_combo_set (GtkComboBox *combo,
 		gtk_combo_box_append_text(combo, node->data);	
 		i++;
 	}
-#endif
 
 	gtk_combo_box_set_active(combo, select);
 	
@@ -634,11 +632,11 @@ prefs_font_create (void)
 	gtk_label_set_mnemonic_widget(GTK_LABEL(label), combo);
 	g_signal_connect (combo, "changed",
 			  G_CALLBACK(cb_serif_entry_changed), prefsui);
-#if GTK_CHECK_VERSION(2,6,0)
+
 	gtk_combo_box_set_row_separator_func(GTK_COMBO_BOX(combo),
 					     combo_box_row_separator_func,
 					     NULL, NULL);
-#endif
+
 	gtk_table_attach(GTK_TABLE(table), combo,
 			 1, 2, 1, 2,
 			 GTK_EXPAND | GTK_FILL, 0,
@@ -665,11 +663,11 @@ prefs_font_create (void)
 	gtk_label_set_mnemonic_widget(GTK_LABEL(label), combo);
 	g_signal_connect (combo, "changed",
 			  G_CALLBACK(cb_sans_serif_entry_changed), prefsui);
-#if GTK_CHECK_VERSION(2,6,0)
+
 	gtk_combo_box_set_row_separator_func(GTK_COMBO_BOX(combo),
 					     combo_box_row_separator_func,
 					     NULL, NULL);
-#endif
+
 	gtk_table_attach(GTK_TABLE(table), combo,
 			 1, 2, 2, 3,
 			 GTK_EXPAND | GTK_FILL, 0,
@@ -696,11 +694,11 @@ prefs_font_create (void)
 	gtk_label_set_mnemonic_widget(GTK_LABEL(label), combo);
 	g_signal_connect (combo, "changed",
 			  G_CALLBACK(cb_monospace_entry_changed), prefsui);
-#if GTK_CHECK_VERSION(2,6,0)
+
 	gtk_combo_box_set_row_separator_func(GTK_COMBO_BOX(combo),
 					     combo_box_row_separator_func,
 					     NULL, NULL);
-#endif
+
 	gtk_table_attach(GTK_TABLE(table), combo,
 			 1, 2, 3, 4,
 			 GTK_EXPAND | GTK_FILL, 0,
